package com.fs.his.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.his.mapper.FsDoctorProductMapper;
import com.fs.his.domain.FsDoctorProduct;
import com.fs.his.service.IFsDoctorProductService;

/**
 * 医生常用商品Service业务层处理
 * 
 * @author fs
 * @date 2023-08-08
 */
@Service
public class FsDoctorProductServiceImpl implements IFsDoctorProductService 
{
    @Autowired
    private FsDoctorProductMapper fsDoctorProductMapper;

    /**
     * 查询医生常用商品
     * 
     * @param id 医生常用商品主键
     * @return 医生常用商品
     */
    @Override
    public FsDoctorProduct selectFsDoctorProductById(Long id)
    {
        return fsDoctorProductMapper.selectFsDoctorProductById(id);
    }

    /**
     * 查询医生常用商品列表
     * 
     * @param fsDoctorProduct 医生常用商品
     * @return 医生常用商品
     */
    @Override
    public List<FsDoctorProduct> selectFsDoctorProductList(FsDoctorProduct fsDoctorProduct)
    {
        return fsDoctorProductMapper.selectFsDoctorProductList(fsDoctorProduct);
    }

    /**
     * 新增医生常用商品
     * 
     * @param fsDoctorProduct 医生常用商品
     * @return 结果
     */
    @Override
    public int insertFsDoctorProduct(FsDoctorProduct fsDoctorProduct)
    {
        return fsDoctorProductMapper.insertFsDoctorProduct(fsDoctorProduct);
    }

    /**
     * 修改医生常用商品
     * 
     * @param fsDoctorProduct 医生常用商品
     * @return 结果
     */
    @Override
    public int updateFsDoctorProduct(FsDoctorProduct fsDoctorProduct)
    {
        return fsDoctorProductMapper.updateFsDoctorProduct(fsDoctorProduct);
    }

    /**
     * 批量删除医生常用商品
     * 
     * @param ids 需要删除的医生常用商品主键
     * @return 结果
     */
    @Override
    public int deleteFsDoctorProductByIds(Long[] ids)
    {
        return fsDoctorProductMapper.deleteFsDoctorProductByIds(ids);
    }

    /**
     * 删除医生常用商品信息
     * 
     * @param id 医生常用商品主键
     * @return 结果
     */
    @Override
    public int deleteFsDoctorProductById(Long id)
    {
        return fsDoctorProductMapper.deleteFsDoctorProductById(id);
    }
}
